## 黄金现货基础信息

接口：sge_basic

描述：获取上海黄金交易所现货合约基础信息

限量：单次最大100条，当前现货合约数不足20个，可以一次提取全部，不需要循环提取

积分：用户积5000积分可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 合约代码 （支持多个，逗号分隔，不输入为获取全部） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 品种代码 |
| ts_name | str | Y | 品种名称 |
| trade_type | str | Y | 交易类型 |
| t_unit | float | Y | 交易单位(克/手) |
| p_unit | float | Y | 报价单位 |
| min_change | float | Y | 最小变动价位 |
| price_limit | float | Y | 每日价格最大波动限制 |
| min_vol | int | Y | 最小单笔报价量(手) |
| max_vol | int | Y | 最大单笔报价量(手) |
| trade_mode | str | Y | 交易期限 |
| margin_rate | float | Y | 保证金比例 |
| liq_rate | float | Y | 违约金比例(%) |
| trade_time | str | Y | 交易时间 |
| list_date | str | Y | 上市日期 |

接口用法

```python
pro = ts.pro_api()

df = pro.sge_basic()
```

或者

```python
df = pro.sge_basic(ts_code='Au99.95')
```

数据样例

```python
ts_code    ts_name  min_vol  max_vol       trade_time
0    Au99.95     黄金9995        1      500     白天：9:00至15:30，夜间:19:50 至次日 02:30
```